/*This shader draw anatomy and highlighting, and depth:
	Texture 0: Anatomy Texture.
	Texture 1: Highlight Texture.
	Texture 2: Anatomy Depth Texture.
	Texture 3: Previous Layer Depth Texture.
*/

uniform int isDepthPeeling;

uniform sampler2D anatomyTexture;
uniform sampler2D highlightTexture;
uniform sampler2D depthTexture;
uniform sampler2DRectShadow DT;

void main()
{
	vec4 previousDepth, anatomyColor, highlightColor, resultColor, depthVector;
	float depth;
	
	//Get the current fragments depth from the passed in depth texture.
	depthVector = texture2D( depthTexture, gl_TexCoord[2].st );

	//Depth values are quantized.
	const vec4 bitShift = vec4( 1.0 / ( 256.0 * 256.0 * 256.0 ), 1.0 / ( 256.0 * 256.0 ), 1.0 / 256.0, 1.0 );
	depth = dot( depthVector, bitShift );

	//Look the previous layer's depth value at this fragment position.
	if( isDepthPeeling == 1 )
	{
		previousDepth = shadow2DRect( DT, gl_FragCoord.stp );
		
		//If the previous layer's depth is greater than or equal to the current fragment's depth, then discard it.
		if( previousDepth.x >= depth )
		{
			discard;
		}
	}
	
	//Get anatomy and highlight color.
	anatomyColor = texture2D( anatomyTexture, gl_TexCoord[0].st );
	highlightColor = texture2D( highlightTexture, gl_TexCoord[1].st );
	
	//Blend the two colors based on the highlight opacity.
	resultColor = anatomyColor * ( 1.0 - highlightColor.a ) + highlightColor * highlightColor.a;
	resultColor.a = anatomyColor.a;
	
	if( depth >= 1.0 )
	{
		resultColor.a = 0.0;
	}
	
	gl_FragColor = resultColor;
	gl_FragDepth = depth;
}