/*This shader draw anatomy and highlighting, and depth:
	Texture 0: Anatomy Texture.
	Texture 1: Highlight Texture.
	Texture 2: Anatomy Depth Texture.
	
	Uniform Variables:
		Float highlightOpacity
*/
uniform sampler2D anatomyTexture;
uniform sampler2D highlightTexture;
uniform sampler2D depthTexture;

void main()
{
	vec4 anatomyColor, highlightColor, resultColor, depthVector;
	float depth;
	
	/*Get anatomy and highlight color*/
	anatomyColor = texture2D( anatomyTexture, gl_TexCoord[0].st );
	highlightColor = texture2D( highlightTexture, gl_TexCoord[1].st );
	
	/*Blend the two colors based on the highlight opacity*/
	resultColor = anatomyColor * ( 1.0 - highlightColor.a ) + highlightColor * highlightColor.a;
	resultColor.a = anatomyColor.a;
	
	depthVector = texture2D( depthTexture, gl_TexCoord[0].st );

	/*Depth values are quantized*/
	const vec4 bitShift = vec4( 1.0 / ( 256.0 * 256.0 * 256.0 ), 1.0 / ( 256.0 * 256.0 ), 1.0 / 256.0, 1.0 );
	depth = dot( depthVector, bitShift );
	
	if( depth >= 1.0 )
	{
		resultColor.a = 0.0;
	}
	
	gl_FragColor = resultColor;
	gl_FragDepth = depth;
}