/*This shader draw anatomy and highlighting, and depth:
	Texture 0: Previous Layer Depth Texture.
	Texture 1: Surface Texture.
	Texture 2: Surface Depth Texture.
*/
$DepthPeel_UniformDefines$

uniform sampler2DRect surfaceTexture;
uniform sampler2DRect surfaceDepthTexture;

uniform float surfaceOpacity;

$ClippingPlane_UniformDefines$

void main()
{
	if( surfaceOpacity <= 0.0 )
	{
		discard;
	}

	vec4 surfaceColor, resultColor, depthVector;
	float depth;
	
	//Get the current fragments depth from the passed in depth texture.
	depthVector = texture2DRect( surfaceDepthTexture, gl_TexCoord[2].st );
	
	//Depth values are quantized.
	const vec4 bitShift = vec4( 1.0 / ( 256.0 * 256.0 * 256.0 ), 1.0 / ( 256.0 * 256.0 ), 1.0 / 256.0, 1.0 );
	depth = dot( depthVector, bitShift ) - 0.0001; //Shift the surface depth towards the camera slightly to avoid colisions.
	
	if( depth >= 1.0 )
	{
		discard;
	}

	$ClippingPlane_ClipTest$
	
	$DepthPeel_DepthTest$

	//Get the surface color.
	surfaceColor = texture2DRect( surfaceTexture, gl_TexCoord[1].st );
	surfaceColor.a = surfaceOpacity;

	gl_FragColor = surfaceColor;
	gl_FragDepth = depth;
}