// VH Dissector < 5.2.27 support
// This doesn't capture Windows versions < 5.2.27 because the user agent string is only modified for requests, not for window.navigator.userAgent object.
// Web based versions could have the server set a cookie that JS could then access to determine if we are running in the VH Dissector.
if( typeof VHDissectorAPI === "undefined" && (window.navigator.userAgent.indexOf( "VHDissector" ) !== -1) ) {
	VHDissectorAPI = new Object();
	
	(function() {
		VHDissectorAPI.isNative = false;
		
		var productName = "VH Dissector";
		var productIdentifier = "net.toltech.VH-Dissector";
		var productVersion = "5.0";
		
		// No need to support stereo, touch, table, etc. as they didn't have releases < 5.2.27
		if( window.navigator.userAgent.indexOf( "VHDissectorLite" ) !== -1 ) {
			productName = "VH Dissector Lite";
			productIdentifier = "net.toltech.VH-Dissector-Lite";
		} else if( window.navigator.userAgent.indexOf( "VHDissectorPro" ) !== -1 ) {
			productName = "VH Dissector Pro";
			productIdentifier = "net.toltech.VH-Dissector-Pro";
		} else if( window.navigator.userAgent.indexOf( "VHDissectorLE-BOTOXInjectionAtlas" ) !== -1 ) {
			productName = "VH Dissector LE - BOTOX Injection Atlas";
			productIdentifier = "net.toltech.VH-Dissector-LE-BIA";
		}
		
		var versionMatch = window.navigator.userAgent.match( /Version\/(5\.[0-2](?:\.[0-9]{1,2})?) VHDissector/ );
		if( versionMatch !== null && versionMatch.length === 2 ) {
			productVersion = versionMatch[1];
		}
		
		VHDissectorAPI.getProductIdentifier = function() {
			return productIdentifier;
		};
		
		VHDissectorAPI.getProductName = function() {
			return productName;
		};
		
		VHDissectorAPI.getProductVersion = function() {
			return productVersion;
		};
		
		var licenseId = "";
		var licenseIdReadyCallbacks = [];
		
		VHDissectorAPI.getLicenseId = function() {
			return licenseId;
		};
		
		VHDissectorAPI.onLicenseIdReady = function( callback ) {
			if( licenseId.length > 0 ) {
				callback();
			} else {
				licenseIdReadyCallbacks.push( callback );
			}
		};
		
		// Global scope so it can be called from the VH Dissector
		setLicenseId = function( id ) {
			licenseId = id;
			while( licenseIdReadyCallbacks.length > 0 ) {
				(licenseIdReadyCallbacks.pop())();
			}
		};
	})();
}

if( typeof VHDissector === "undefined" ) {
	VHDissector = new Object();
	
	(function() {
		var isAPIAvailable = (typeof VHDissectorAPI !== "undefined");
		var isAPINative = isAPIAvailable && (typeof VHDissectorAPI.isNative !== "boolean");
		
		// Core functions provided with all VH Dissector versions.
		VHDissector.getProductName = function() {
			return isAPIAvailable ? VHDissectorAPI.getProductName() : "VH Dissector Online";
		};
		
		VHDissector.getProductIdentifier = function() {
			return isAPIAvailable ? VHDissectorAPI.getProductIdentifier() : "";
		}
		
		VHDissector.getProductVersion = function() {
			return isAPIAvailable ? VHDissectorAPI.getProductVersion() : "";
		}
		
		VHDissector.getBodyClasses = function() {
			return isAPIAvailable ? "vh-dissector " + VHDissectorAPI.getProductIdentifier().toLowerCase().split( '.' ).pop() : "";
		};
		
		VHDissector.getLicenseId = function() {
			return isAPIAvailable ? VHDissectorAPI.getLicenseId() : "";
		};
		
		VHDissector.onLicenseIdReady = function( callback ) {
			if( isAPIAvailable ) {
				if( isAPINative ) {
					callback();
				} else {
					VHDissectorAPI.onLicenseIdReady( callback );
				}
			}
		};
		
		VHDissector.getInstalledLessons = function() {
			// JSON.parse isn't available in IE8.
			return isAPINative && (typeof JSON !== "undefined") ? JSON.parse( VHDissectorAPI.getInstalledLessons() ) : [];
		};
		
		// We need this because for security reasons we can't insert a file link into an http/s page.
		VHDissector.goToInstalledLessonWithIndex = function( index ) {
			if( isAPINative ) {
				VHDissectorAPI.goToInstalledLessonWithIndex( index );
			}
		};
	})();
}